---
title: <span class="badge object-type-scalar"></span> CubicDecimeter
---
# <span class="badge object-type-scalar"></span> CubicDecimeter

Volume: cubic decimeter

## Definition

```python
# Volume: cubic decimeter
CubicDecimeter: typing.Literal["dm3"] = "dm3"
```
